@@ -38,7 +38,7 @@
 #include <pthread.h>
 #include <sys/wait.h>
 #include <sys/types.h>
-#include <sys/unistd.h>
+#include <unistd.h>
 #include <netinet/in.h>
 #include <sys/ioctl.h>
 #include <arpa/inet.h>
@@ -162,7 +162,8 @@ execute(const char cmd_line[], int quiet)
 }
 
 struct in_addr *
-wd_gethostbyname(const char name[]) {
+wd_gethostbyname(const char name[])
+{
 	struct hostent *he;
 	struct in_addr *h_addr, *in_addr_temp;
 
@@ -738,7 +739,7 @@ get_clients_json(void)
 
 	snprintf((buffer + len), (sizeof(buffer) - len), "\"clients\":{\n");
 	len = strlen(buffer);
-	
+
 	while (client != NULL) {
 		snprintf((buffer + len), (sizeof(buffer) - len), "\"%s\":{\n", client->mac);
 		len = strlen(buffer);
